{% extends "wagtailadmin/base.html" %}
{% load i18n %}
{% block titletag %}{% trans "Link Checker" %}{% endblock %}
{% block bodyclass %}menu-linkchecker{% endblock %}
{% block content %}

    {% include "wagtailadmin/shared/header.html" with title="Link Checker" icon="link" %}

    <div class="nice-padding">
		<form method="POST" action=''>
			{% csrf_token %}
			{{edit_handler.render_form_content}}
            <input type="submit" value="{% trans 'Save' %}" class="button" />
		</form>

        <hr>
        <h3> The button below will conduct a site wide scan for broken links. </h3>
        <div class="addbutton">
            <a href="{% url 'wagtaillinkchecker_scan' %}" class="button">Conduct Scan</a>
        </div>
    </div>
{% endblock %}
