{% extends "wagtailadmin/base.html" %}
{% load i18n %}
{% block titletag %}{% trans "Link Checker Results" %}{% endblock %}
{% block bodyclass %}menu-linkchecker{% endblock %}
{% block content %}

    {% include "wagtailadmin/shared/header.html" with title="Link Checker" icon="link" %}

    <div class="nice-padding">
		{% for link in broken_links %}
		<p>
            <a href='{{link}}' target="_blank">{{link}}</a> - {{link.message}}
            <a href="{% url 'wagtailadmin_pages:edit' link.page.id %}" target="_blank" class="button button-small">Edit page containing this link</a>
        </p>
		{% endfor %}
        <a href="{% url 'wagtaillinkchecker' %}" class="button bicolor icon icon-arrow-left">Back</a>
    </div>
{% endblock %}
